@@ -80,3 +80,19 @@ stealth_sample.int <- function(n, size = n, replace = FALSE, ...) {
   on.exit(.GlobalEnv$.Random.seed <- oseed)
   sample.int(n = n, size = size, replace = replace, ...)
 }
+
+
+import_from <- function(name, default = NULL, package) {
+  ns <- getNamespace(package)
+  if (exists(name, mode = "function", envir = ns, inherits = FALSE)) {
+    get(name, mode = "function", envir = ns, inherits = FALSE)
+  } else if (!is.null(default)) {
+    default
+  } else {
+    stop(sprintf("No such '%s' function: %s()", package, name))
+  }
+}
+
+import_future <- function(name, default = NULL) {
+  import_from(name, default = default, package = "future")
+}
